==> hibernate-core-6.0.0.Final-sources.jar: cfg/org/hibernate/boot/jaxb/cfg/spi/ObjectFactory.java <==

package org.hibernate.boot.jaxb.cfg.spi;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.hibernate.boot.jaxb.cfg.spi package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.hibernate.boot.jaxb.cfg.spi
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link JaxbCfgHibernateConfiguration }
     * 
     */
    public JaxbCfgHibernateConfiguration createJaxbCfgHibernateConfiguration() {
        return new JaxbCfgHibernateConfiguration();
    }

    /**
     * Create an instance of {@link JaxbCfgHibernateConfiguration.JaxbCfgSecurity }
     * 
     */
    public JaxbCfgHibernateConfiguration.JaxbCfgSecurity createJaxbCfgHibernateConfigurationJaxbCfgSecurity() {
        return new JaxbCfgHibernateConfiguration.JaxbCfgSecurity();
    }

    /**
     * Create an instance of {@link JaxbCfgHibernateConfiguration.JaxbCfgSessionFactory }
     * 
     */
    public JaxbCfgHibernateConfiguration.JaxbCfgSessionFactory createJaxbCfgHibernateConfigurationJaxbCfgSessionFactory() {
        return new JaxbCfgHibernateConfiguration.JaxbCfgSessionFactory();
    }

    /**
     * Create an instance of {@link JaxbCfgConfigPropertyType }
     * 
     */
    public JaxbCfgConfigPropertyType createJaxbCfgConfigPropertyType() {
        return new JaxbCfgConfigPropertyType();
    }

    /**
     * Create an instance of {@link JaxbCfgMappingReferenceType }
     * 
     */
    public JaxbCfgMappingReferenceType createJaxbCfgMappingReferenceType() {
        return new JaxbCfgMappingReferenceType();
    }

    /**
     * Create an instance of {@link JaxbCfgEntityCacheType }
     * 
     */
    public JaxbCfgEntityCacheType createJaxbCfgEntityCacheType() {
        return new JaxbCfgEntityCacheType();
    }

    /**
     * Create an instance of {@link JaxbCfgCollectionCacheType }
     * 
     */
    public JaxbCfgCollectionCacheType createJaxbCfgCollectionCacheType() {
        return new JaxbCfgCollectionCacheType();
    }

    /**
     * Create an instance of {@link JaxbCfgEventListenerGroupType }
     * 
     */
    public JaxbCfgEventListenerGroupType createJaxbCfgEventListenerGroupType() {
        return new JaxbCfgEventListenerGroupType();
    }

    /**
     * Create an instance of {@link JaxbCfgEventListenerType }
     * 
     */
    public JaxbCfgEventListenerType createJaxbCfgEventListenerType() {
        return new JaxbCfgEventListenerType();
    }

    /**
     * Create an instance of {@link JaxbCfgHibernateConfiguration.JaxbCfgSecurity.JaxbCfgGrant }
     * 
     */
    public JaxbCfgHibernateConfiguration.JaxbCfgSecurity.JaxbCfgGrant createJaxbCfgHibernateConfigurationJaxbCfgSecurityJaxbCfgGrant() {
        return new JaxbCfgHibernateConfiguration.JaxbCfgSecurity.JaxbCfgGrant();
    }

}

==> hibernate-core-6.2.13.Final-sources.jar: cfg/org/hibernate/boot/jaxb/cfg/spi/ObjectFactory.java <==

package org.hibernate.boot.jaxb.cfg.spi;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.hibernate.boot.jaxb.cfg.spi package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.hibernate.boot.jaxb.cfg.spi
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link JaxbCfgHibernateConfiguration }
     * 
     * @return
     *     the new instance of {@link JaxbCfgHibernateConfiguration }
     */
    public JaxbCfgHibernateConfiguration createJaxbCfgHibernateConfiguration() {
        return new JaxbCfgHibernateConfiguration();
    }

    /**
     * Create an instance of {@link JaxbCfgHibernateConfiguration.JaxbCfgSecurity }
     * 
     * @return
     *     the new instance of {@link JaxbCfgHibernateConfiguration.JaxbCfgSecurity }
     */
    public JaxbCfgHibernateConfiguration.JaxbCfgSecurity createJaxbCfgHibernateConfigurationJaxbCfgSecurity() {
        return new JaxbCfgHibernateConfiguration.JaxbCfgSecurity();
    }

    /**
     * Create an instance of {@link JaxbCfgHibernateConfiguration.JaxbCfgSessionFactory }
     * 
     * @return
     *     the new instance of {@link JaxbCfgHibernateConfiguration.JaxbCfgSessionFactory }
     */
    public JaxbCfgHibernateConfiguration.JaxbCfgSessionFactory createJaxbCfgHibernateConfigurationJaxbCfgSessionFactory() {
        return new JaxbCfgHibernateConfiguration.JaxbCfgSessionFactory();
    }

    /**
     * Create an instance of {@link JaxbCfgConfigPropertyType }
     * 
     * @return
     *     the new instance of {@link JaxbCfgConfigPropertyType }
     */
    public JaxbCfgConfigPropertyType createJaxbCfgConfigPropertyType() {
        return new JaxbCfgConfigPropertyType();
    }

    /**
     * Create an instance of {@link JaxbCfgMappingReferenceType }
     * 
     * @return
     *     the new instance of {@link JaxbCfgMappingReferenceType }
     */
    public JaxbCfgMappingReferenceType createJaxbCfgMappingReferenceType() {
        return new JaxbCfgMappingReferenceType();
    }

    /**
     * Create an instance of {@link JaxbCfgEntityCacheType }
     * 
     * @return
     *     the new instance of {@link JaxbCfgEntityCacheType }
     */
    public JaxbCfgEntityCacheType createJaxbCfgEntityCacheType() {
        return new JaxbCfgEntityCacheType();
    }

    /**
     * Create an instance of {@link JaxbCfgCollectionCacheType }
     * 
     * @return
     *     the new instance of {@link JaxbCfgCollectionCacheType }
     */
    public JaxbCfgCollectionCacheType createJaxbCfgCollectionCacheType() {
        return new JaxbCfgCollectionCacheType();
    }

    /**
     * Create an instance of {@link JaxbCfgEventListenerGroupType }
     * 
     * @return
     *     the new instance of {@link JaxbCfgEventListenerGroupType }
     */
    public JaxbCfgEventListenerGroupType createJaxbCfgEventListenerGroupType() {
        return new JaxbCfgEventListenerGroupType();
    }

    /**
     * Create an instance of {@link JaxbCfgEventListenerType }
     * 
     * @return
     *     the new instance of {@link JaxbCfgEventListenerType }
     */
    public JaxbCfgEventListenerType createJaxbCfgEventListenerType() {
        return new JaxbCfgEventListenerType();
    }

    /**
     * Create an instance of {@link JaxbCfgHibernateConfiguration.JaxbCfgSecurity.JaxbCfgGrant }
     * 
     * @return
     *     the new instance of {@link JaxbCfgHibernateConfiguration.JaxbCfgSecurity.JaxbCfgGrant }
     */
    public JaxbCfgHibernateConfiguration.JaxbCfgSecurity.JaxbCfgGrant createJaxbCfgHibernateConfigurationJaxbCfgSecurityJaxbCfgGrant() {
        return new JaxbCfgHibernateConfiguration.JaxbCfgSecurity.JaxbCfgGrant();
    }

}
